@@ -4,12 +4,14 @@
 
 GeoKrigloc= function(data, coordx, coordy=NULL, coordt=NULL, coordx_dyn=NULL, corrmodel, distance="Eucl", grid=FALSE, loc,neighb=NULL,
               maxdist=NULL,maxtime=NULL, method="cholesky", model="Gaussian", n=1,nloc=NULL, mse=FALSE,  param, anisopars=NULL, 
-              radius=6371, sparse=FALSE, time=NULL, type="Standard",type_mse=NULL, type_krig="Simple",weigthed=TRUE, which=1,copula=NULL, X=NULL,Xloc=NULL)
+              radius=6371, sparse=FALSE, time=NULL, type="Standard",
+              type_mse=NULL, type_krig="Simple",weigthed=TRUE, which=1,copula=NULL, X=NULL,Xloc=NULL,Mloc=NULL)
 
 
 {
 
 ## X and more stuuffs..
+M=NULL
 spacetime=FALSE
 bivariate=FALSE
 if(!is.null(coordt)) spacetime=TRUE
@@ -31,23 +33,33 @@ Nloc=nrow(loc)
 Tloc=length(time)
 if(bivariate)  Tloc=1
 
+if(length(param$mean)>1) M=param$mean
+
+
 
 #####################################################################
 if(space){
          ### computing spatial neighborhood
-         neigh=GeoNeighborhood(data, coordx=coords,distance=distance,loc=loc,neighb=neighb,maxdist=maxdist,X=X)
+         neigh=GeoNeighborhood(data, coordx=coords,distance=distance,loc=loc,neighb=neighb,maxdist=maxdist,X=X,M=M)
          res1=res2=NULL
          #  pb <- txtProgressBar(min = 0, max = Nloc, style = 3)
+         
+         
          for(i in 1: Nloc)
           {
+              #update mean
+         if(!is.null(M)) param$mean=neigh$M[[i]]
         #    Sys.sleep(0.1)
+                  #print(loc[i,]);print(neigh$coordx[[i]]);print(Mloc[i]);print(param)
             pr=GeoKrig(loc=loc[i,],coordx=neigh$coordx[[i]],corrmodel=corrmodel,distance=distance,n=n,
-                X=neigh$X[[i]],Xloc= Xloc[i,],
+                X=neigh$X[[i]],Xloc= Xloc[i,],Mloc=Mloc[i],
                 model=model, param=param,anisopars=anisopars, mse=mse, data=neigh$data[[i]],copula=copula)
                 res1=c(res1,pr$pred)
                 res2=c(res2,pr$mse)
+
          #   setTxtProgressBar(pb, i)
          #   close(pb)
+    
           }
 }
 ######################################################################
